@@ -8,7 +8,7 @@ die "Usage: perl support.pl <what_to_lookup>\n"
 
 my $What = shift;
 
-use lib '../lib';
+use lib qw(../lib  lib);
 use POE qw(Component::WWW::WebDevout::BrowserSupportInfo);
 
 my $poco = POE::Component::WWW::WebDevout::BrowserSupportInfo->spawn(
@@ -38,7 +38,7 @@ sub fetched {
     my $in = $_[ARG0];
 
     print "Support for $in->{what}\n";
-    print "\t$_ => $in->{results}{ $_ }\n"
+    print "\t$_ => ${\(defined $in->{results}{ $_ } ? $in->{results}{ $_ } : '')}\n"
         for keys %{ $in->{results} };
 
     print "For more information visit: $in->{uri_info}\n";
